# web3_wrapped_contract

![PyPI - package version](https://img.shields.io/pypi/v/web3_wrapped_contract?logo=pypi&style=flat-square)
![PyPI - license](https://img.shields.io/pypi/l/web3_wrapped_contract?label=package%20license&style=flat-square)
![PyPI - python version](https://img.shields.io/pypi/pyversions/web3_wrapped_contract?logo=pypi&style=flat-square)
![PyPI - downloads](https://img.shields.io/pypi/dm/web3_wrapped_contract?logo=pypi&style=flat-square)

![GitHub - last commit](https://img.shields.io/github/last-commit/kkristof200/py_web3_wrapped_contract?style=flat-square)
![GitHub - commit activity](https://img.shields.io/github/commit-activity/m/kkristof200/py_web3_wrapped_contract?style=flat-square)

![GitHub - code size in bytes](https://img.shields.io/github/languages/code-size/kkristof200/py_web3_wrapped_contract?style=flat-square)
![GitHub - repo size](https://img.shields.io/github/repo-size/kkristof200/py_web3_wrapped_contract?style=flat-square)
![GitHub - lines of code](https://img.shields.io/tokei/lines/github/kkristof200/py_web3_wrapped_contract?style=flat-square)

![GitHub - license](https://img.shields.io/github/license/kkristof200/py_web3_wrapped_contract?label=repo%20license&style=flat-square)

## Description

web3_wrapped_contract

## Install

~~~~bash
pip install web3_wrapped_contract
# or
pip3 install web3_wrapped_contract
~~~~

## Usage

~~~~python
import web3_wrapped_contract
~~~~

## Dependencies

[eth-account](https://pypi.org/project/eth-account), [web3](https://pypi.org/project/web3)